==> ugene_1.25.0+dfsg.orig.tar.xz: ugene-1.25.0/src/plugins/external_tool_support/src/hmmer/HmmerBuildFromMsaTask.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_HMMER_BUILD_FROM_MSA_TASK_H_
#define _U2_HMMER_BUILD_FROM_MSA_TASK_H_

#include <U2Core/MAlignment.h>

#include "HmmerBuildTask.h"

namespace U2 {

class HmmerBuildFromMsaTask : public ExternalToolSupportTask {
    Q_OBJECT
public:
    HmmerBuildFromMsaTask(const HmmerBuildSettings &settings, const MAlignment &msa);

    const QString & getHmmUrl() const;

private:
    void prepare();
    QList<Task *> onSubTaskFinished(Task *subTask);
    QString generateReport() const;

    void prepareWorkingDir();
    void removeTempDir();

    HmmerBuildSettings settings;
    const MAlignment msa;

    SaveAlignmentTask *saveTask;
    HmmerBuildTask *hmmerTask;
    bool removeWorkingDir;
};

}   // namespace U2

#endif // _U2_HMMER_BUILD_FROM_MSA_TASK_H_

==> ugene_33.0+dfsg.orig.tar.xz: ugene-33.0/src/plugins/external_tool_support/src/hmmer/HmmerBuildFromMsaTask.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_HMMER_BUILD_FROM_MSA_TASK_H_
#define _U2_HMMER_BUILD_FROM_MSA_TASK_H_

#include <U2Core/MultipleSequenceAlignment.h>

#include "HmmerBuildTask.h"

namespace U2 {

class HmmerBuildFromMsaTask : public ExternalToolSupportTask {
    Q_OBJECT
public:
    HmmerBuildFromMsaTask(const HmmerBuildSettings &settings, const MultipleSequenceAlignment &msa);

    const QString & getHmmUrl() const;

private:
    void prepare();
    QList<Task *> onSubTaskFinished(Task *subTask);
    QString generateReport() const;

    void prepareWorkingDir();
    void removeTempDir();

    HmmerBuildSettings settings;
    const MultipleSequenceAlignment msa;

    SaveAlignmentTask *saveTask;
    HmmerBuildTask *hmmerTask;
    bool removeWorkingDir;
};

}   // namespace U2

#endif // _U2_HMMER_BUILD_FROM_MSA_TASK_H_
